@@ -3,6 +3,8 @@ import logging
 from pathlib import Path
 from typing import List, Union
 
+import chardet
+
 from deptry.notebook_import_extractor import NotebookImportExtractor
 
 RECURSION_TYPES = [ast.If, ast.Try, ast.ExceptHandler, ast.FunctionDef, ast.ClassDef]
@@ -22,6 +24,7 @@ class ImportParser:
         modules_per_file = [self.get_imported_modules_from_file(file) for file in list_of_files]
         all_modules = self._flatten_list(modules_per_file)
         unique_modules = sorted(list(set(all_modules)))
+        unique_modules = self._filter_exceptions(unique_modules)
         logging.debug(f"All imported modules: {unique_modules}\n")
         return unique_modules
 
@@ -44,7 +47,7 @@ class ImportParser:
         return self._get_import_modules_from(import_nodes)
 
     def _get_imported_modules_from_py(self, path_to_py_file: Path) -> List[str]:
-        with open(path_to_py_file) as f:
+        with open(path_to_py_file, encoding=self._get_file_encoding(path_to_py_file)) as f:
             root = ast.parse(f.read(), path_to_py_file)  # type: ignore
         import_nodes = self._get_import_nodes_from(root)
         return self._get_import_modules_from(import_nodes)
@@ -77,7 +80,9 @@ class ImportParser:
             if isinstance(node, ast.Import):
                 modules += [x.name.split(".")[0] for x in node.names]
             elif isinstance(node, ast.ImportFrom):
-                if node.module:  # nodes for imports like `from . import foo` do not have a module attribute.
+                if (
+                    node.module and node.level == 0
+                ):  # nodes for imports like `from . import foo` do not have a module attribute.
                     modules.append(node.module.split(".")[0])  # type: ignore
         return modules
 
@@ -88,3 +93,19 @@ class ImportParser:
             if modules:
                 all_modules += modules
         return all_modules
+
+    @staticmethod
+    def _filter_exceptions(modules: List[str]):
+        exceptions = [
+            "setuptools"
+        ]  # setuptools is usually available by default, so often not specified in dependencies.
+        for exception in exceptions:
+            if exception in modules:
+                logging.debug(f"Found module {exception} to be imported, omitting from the list of modules.")
+                modules = [module for module in modules if not module == exception]
+        return modules
+
+    @staticmethod
+    def _get_file_encoding(file_name: Union[str, Path]) -> str:
+        rawdata = open(file_name, "rb").read()
+        return chardet.detect(rawdata)["encoding"]
